Learn R Programming

journalR (version 0.6.0)

drop_column: Drop a column from a data.frame or data.table, preserving class and modifying in place if data.table.

Description

Drop a column from a data.frame or data.table, preserving class and modifying in place if data.table.

Usage

drop_column(x, varname)

Value

[data.frame or data.table] input `x` with column dropped

Arguments

x

[data.frame or data.table]

varname

[chr] column name to drop

See Also

Other column_mods: add_column(), drop_columns()